PaymobPaymentResult class

Represents the result of a Paymob payment transaction

Constructors

PaymobPaymentResult({required PaymentStatus status, Map<String, dynamic>? transactionDetails, String? errorMessage})

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
isPending bool
Returns true if the payment is pending
no setter
isRejected bool
Returns true if the payment was rejected
no setter
isSuccessful bool
Returns true if the payment was successful
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaymentStatus
final
transactionDetails Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited