PaymobService class
Main service class for integrating Paymob payment SDK
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPaymentIntention(
{bool useSecureMode = true, String? secretKey, required String publicKey, String? clientSecret, int? amount, String? currency, int? integrationId, Map< String, dynamic> ? billingData, List<Map< ? items}) → Future<String, dynamic> >Map< String, String> > - Creates a payment intention and returns the credentials needed for SDK
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
payWithPaymob(
{required String publicKey, required String clientSecret, PaymobCustomization? customization}) → Future< PaymobPaymentResult> - Initiates a payment using the Paymob SDK
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited